==============================
 sphinxcontrib-paverutils 1.6
==============================

.. tags:: python, sphinx, sphinxcontrib-paverutils, release

What is sphinxcontrib-paverutils?
=================================

`sphinxcontrib-paverutils`_ provides an alternative integration of
Sphinx_ and Paver_. It supports calling Sphinx from within Paver using
multiple configurations, and does not assume you only want to build
HTML output.

.. _Sphinx: http://sphinx-doc.org/
.. _Paver: http://www.blueskyonmars.com/projects/paver/
.. _sphinxcontrib-paverutils: https://bitbucket.org/dhellmann/sphinxcontrib-paverutils/


What's New in This Release?
===========================

- Improve Python 3 support
- Clean up packaging using pbr_
- redefine cog to allow it to run on specific input file(s)

.. _pbr: https://pypi.python.org/pypi/pbr
